@@ -15,9 +15,9 @@
 #                                                                             #
 ###############################################################################
 
-import logging
 from collections import defaultdict
 
+import dendropy
 from numpy import (median as np_median,
                    array as np_array,
                    arange as np_arange,
@@ -38,14 +38,10 @@ class RelativeDistance(object):
 
     def __init__(self):
         """Initialization."""
-        self.logger = logging.getLogger()
 
-        # Options = namedtuple('Options', 'width height tick_font_size label_font_size dpi')
-        # options = Options(6, 6, 12, 12, 96)
-        # AbstractPlot.__init__(self, options)
-        # self.dpi = 96
+        pass
 
-    def _avg_descendant_rate(self, tree):
+    def _avg_descendant_rate(self, root_node):
         """Calculate average rate of divergence for each nodes in a tree.
 
         The average rate is the arithmetic mean of the
@@ -53,8 +49,8 @@ class RelativeDistance(object):
 
         Parameters
         ----------
-        tree : Dendropy Tree
-            Phylogenetic tree.
+        root_node : Dendropy Node
+            Root node defining tree or subtree.
 
         Returns
         -------
@@ -64,7 +60,7 @@ class RelativeDistance(object):
         """
 
         # calculate the mean branch length to extant taxa
-        for node in tree.postorder_node_iter():
+        for node in root_node.postorder_iter():
             avg_div = 0
             if node.is_leaf():
                 node.mean_dist = 0.0
@@ -74,17 +70,17 @@ class RelativeDistance(object):
                 for c in node.child_node_iter():
                     num_tips = c.num_taxa
                     avg_div += (float(c.num_taxa) / node.num_taxa) * \
-                        (c.mean_dist + c.edge_length)
+                               (c.mean_dist + c.edge_length)
 
             node.mean_dist = avg_div
 
-    def decorate_rel_dist(self, tree):
+    def decorate_rel_dist(self, root_node, root_red=0.0):
         """Calculate relative distance to each internal node.
 
         Parameters
         ----------
-        tree : Dendropy Tree
-            Phylogenetic tree.
+        root_node : Dendropy Node
+            Root node defining tree or subtree.
 
         Returns
         -------
@@ -94,11 +90,14 @@ class RelativeDistance(object):
           rel_dists: relative distance of node between root and extant organisms
         """
 
-        self._avg_descendant_rate(tree)
+        if isinstance(root_node, dendropy.Tree):
+            root_node = root_node.seed_node
 
-        for node in tree.preorder_node_iter():
-            if node == tree.seed_node:
-                node.rel_dist = 0.0
+        self._avg_descendant_rate(root_node)
+
+        for node in root_node.preorder_iter():
+            if node == root_node:
+                node.rel_dist = root_red
             elif node.is_leaf():
                 node.rel_dist = 1.0
             else:
